@@ -45,24 +45,9 @@ from .fetchers import NUEgressACLEntryTemplatesFetcher
 from .fetchers import NUEgressACLTemplatesFetcher
 
 
-from .fetchers import NUDomainFIPAclTemplatesFetcher
-
-
-from .fetchers import NUFloatingIPACLTemplatesFetcher
-
-
 from .fetchers import NUDHCPOptionsFetcher
 
 
-from .fetchers import NULinksFetcher
-
-
-from .fetchers import NULinksFetcher
-
-
-from .fetchers import NULinksFetcher
-
-
 from .fetchers import NUFloatingIpsFetcher
 
 
@@ -102,21 +87,12 @@ from .fetchers import NUDomainTemplatesFetcher
 from .fetchers import NUZonesFetcher
 
 
-from .fetchers import NUContainersFetcher
-
-
-from .fetchers import NUContainerInterfacesFetcher
-
-
 from .fetchers import NUQOSsFetcher
 
 
 from .fetchers import NUHostInterfacesFetcher
 
 
-from .fetchers import NURoutingPoliciesFetcher
-
-
 from .fetchers import NUUplinkRDsFetcher
 
 
@@ -126,9 +102,6 @@ from .fetchers import NUVPNConnectionsFetcher
 from .fetchers import NUVPortsFetcher
 
 
-from .fetchers import NUApplicationperformancemanagementbindingsFetcher
-
-
 from .fetchers import NUBridgeInterfacesFetcher
 
 
@@ -159,7 +132,7 @@ class NUDomain(NURESTObject):
     """ Represents a Domain in the VSD
 
         Notes:
-            This object is used to manipulate domain state. A domain corresponds to a distributed Virtual Router and Switch.
+            This object is used to manipulate domain state. A domain corresponds to a distributed Virtual Router and Switch (dVRS).
     """
 
     __rest_name__ = "domain"
@@ -180,7 +153,7 @@ class NUDomain(NURESTObject):
     
     CONST_DHCP_BEHAVIOR_CONSUME = "CONSUME"
     
-    CONST_DPI_ENABLED = "ENABLED"
+    CONST_APPLICATION_DEPLOYMENT_POLICY_NONE = "NONE"
     
     CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
     
@@ -218,8 +191,6 @@ class NUDomain(NURESTObject):
     
     CONST_MULTICAST_INHERITED = "INHERITED"
     
-    CONST_APPLICATION_DEPLOYMENT_POLICY_NONE = "NONE"
-    
     CONST_UPLINK_PREFERENCE_SECONDARY = "SECONDARY"
     
     CONST_DHCP_BEHAVIOR_FLOOD = "FLOOD"
@@ -236,8 +207,6 @@ class NUDomain(NURESTObject):
     
     CONST_UPLINK_PREFERENCE_PRIMARY = "PRIMARY"
     
-    CONST_DPI_DISABLED = "DISABLED"
-    
     CONST_MAINTENANCE_MODE_ENABLED_INHERITED = "ENABLED_INHERITED"
     
     CONST_ENCRYPTION_ENABLED = "ENABLED"
@@ -269,15 +238,11 @@ class NUDomain(NURESTObject):
         
         self._pat_enabled = None
         self._ecmp_count = None
-        self._bgp_enabled = None
         self._dhcp_behavior = None
         self._dhcp_server_address = None
-        self._dpi = None
         self._label_id = None
         self._back_haul_route_distinguisher = None
         self._back_haul_route_target = None
-        self._back_haul_subnet_ip_address = None
-        self._back_haul_subnet_mask = None
         self._back_haul_vnid = None
         self._maintenance_mode = None
         self._name = None
@@ -295,14 +260,11 @@ class NUDomain(NURESTObject):
         self._underlay_enabled = None
         self._entity_scope = None
         self._policy_change_status = None
-        self._domain_id = None
         self._route_distinguisher = None
         self._route_target = None
         self._uplink_preference = None
         self._application_deployment_policy = None
-        self._associated_bgp_profile_id = None
         self._associated_multicast_channel_map_id = None
-        self._associated_pat_mapper_id = None
         self._stretched = None
         self._multicast = None
         self._tunnel_type = None
@@ -312,15 +274,11 @@ class NUDomain(NURESTObject):
         
         self.expose_attribute(local_name="pat_enabled", remote_name="PATEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="ecmp_count", remote_name="ECMPCount", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="bgp_enabled", remote_name="BGPEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dhcp_behavior", remote_name="DHCPBehavior", attribute_type=str, is_required=False, is_unique=False, choices=[u'CONSUME', u'FLOOD', u'RELAY'])
         self.expose_attribute(local_name="dhcp_server_address", remote_name="DHCPServerAddress", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED'])
         self.expose_attribute(local_name="label_id", remote_name="labelID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="back_haul_route_distinguisher", remote_name="backHaulRouteDistinguisher", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="back_haul_route_target", remote_name="backHaulRouteTarget", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="back_haul_subnet_ip_address", remote_name="backHaulSubnetIPAddress", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="back_haul_subnet_mask", remote_name="backHaulSubnetMask", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="back_haul_vnid", remote_name="backHaulVNID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="maintenance_mode", remote_name="maintenanceMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'ENABLED_INHERITED'])
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
@@ -338,14 +296,11 @@ class NUDomain(NURESTObject):
         self.expose_attribute(local_name="underlay_enabled", remote_name="underlayEnabled", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="policy_change_status", remote_name="policyChangeStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'APPLIED', u'DISCARDED', u'STARTED'])
-        self.expose_attribute(local_name="domain_id", remote_name="domainID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="route_distinguisher", remote_name="routeDistinguisher", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="route_target", remote_name="routeTarget", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="uplink_preference", remote_name="uplinkPreference", attribute_type=str, is_required=False, is_unique=False, choices=[u'PRIMARY', u'PRIMARY_SECONDARY', u'SECONDARY', u'SECONDARY_PRIMARY', u'SYMMETRIC'])
         self.expose_attribute(local_name="application_deployment_policy", remote_name="applicationDeploymentPolicy", attribute_type=str, is_required=False, is_unique=False, choices=[u'NONE', u'ZONE'])
-        self.expose_attribute(local_name="associated_bgp_profile_id", remote_name="associatedBGPProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_multicast_channel_map_id", remote_name="associatedMulticastChannelMapID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="associated_pat_mapper_id", remote_name="associatedPATMapperID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stretched", remote_name="stretched", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="tunnel_type", remote_name="tunnelType", attribute_type=str, is_required=False, is_unique=False, choices=[u'DC_DEFAULT', u'GRE', u'VXLAN'])
@@ -375,24 +330,9 @@ class NUDomain(NURESTObject):
         self.egress_acl_templates = NUEgressACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.domain_fip_acl_templates = NUDomainFIPAclTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.floating_ipacl_templates = NUFloatingIPACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.dhcp_options = NUDHCPOptionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.links = NULinksFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.links = NULinksFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.links = NULinksFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.floating_ips = NUFloatingIpsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -432,21 +372,12 @@ class NUDomain(NURESTObject):
         self.zones = NUZonesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.containers = NUContainersFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.container_interfaces = NUContainerInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.qoss = NUQOSsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.host_interfaces = NUHostInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.routing_policies = NURoutingPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.uplink_rds = NUUplinkRDsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -456,9 +387,6 @@ class NUDomain(NURESTObject):
         self.vports = NUVPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.applicationperformancemanagementbindings = NUApplicationperformancemanagementbindingsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.bridge_interfaces = NUBridgeInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -541,33 +469,6 @@ class NUDomain(NURESTObject):
         self._ecmp_count = value
 
     
-    @property
-    def bgp_enabled(self):
-        """ Get bgp_enabled value.
-
-            Notes:
-                Read only flag to display if BGP is enabled for this domain
-
-                
-                This attribute is named `BGPEnabled` in VSD API.
-                
-        """
-        return self._bgp_enabled
-
-    @bgp_enabled.setter
-    def bgp_enabled(self, value):
-        """ Set bgp_enabled value.
-
-            Notes:
-                Read only flag to display if BGP is enabled for this domain
-
-                
-                This attribute is named `BGPEnabled` in VSD API.
-                
-        """
-        self._bgp_enabled = value
-
-    
     @property
     def dhcp_behavior(self):
         """ Get dhcp_behavior value.
@@ -622,33 +523,6 @@ class NUDomain(NURESTObject):
         self._dhcp_server_address = value
 
     
-    @property
-    def dpi(self):
-        """ Get dpi value.
-
-            Notes:
-                determines whether or not Deep packet inspection is enabled
-
-                
-                This attribute is named `DPI` in VSD API.
-                
-        """
-        return self._dpi
-
-    @dpi.setter
-    def dpi(self, value):
-        """ Set dpi value.
-
-            Notes:
-                determines whether or not Deep packet inspection is enabled
-
-                
-                This attribute is named `DPI` in VSD API.
-                
-        """
-        self._dpi = value
-
-    
     @property
     def label_id(self):
         """ Get label_id value.
@@ -730,60 +604,6 @@ class NUDomain(NURESTObject):
         self._back_haul_route_target = value
 
     
-    @property
-    def back_haul_subnet_ip_address(self):
-        """ Get back_haul_subnet_ip_address value.
-
-            Notes:
-                IP Address of the backhaul subnet 
-
-                
-                This attribute is named `backHaulSubnetIPAddress` in VSD API.
-                
-        """
-        return self._back_haul_subnet_ip_address
-
-    @back_haul_subnet_ip_address.setter
-    def back_haul_subnet_ip_address(self, value):
-        """ Set back_haul_subnet_ip_address value.
-
-            Notes:
-                IP Address of the backhaul subnet 
-
-                
-                This attribute is named `backHaulSubnetIPAddress` in VSD API.
-                
-        """
-        self._back_haul_subnet_ip_address = value
-
-    
-    @property
-    def back_haul_subnet_mask(self):
-        """ Get back_haul_subnet_mask value.
-
-            Notes:
-                Network mask of the backhaul subnet
-
-                
-                This attribute is named `backHaulSubnetMask` in VSD API.
-                
-        """
-        return self._back_haul_subnet_mask
-
-    @back_haul_subnet_mask.setter
-    def back_haul_subnet_mask(self, value):
-        """ Set back_haul_subnet_mask value.
-
-            Notes:
-                Network mask of the backhaul subnet
-
-                
-                This attribute is named `backHaulSubnetMask` in VSD API.
-                
-        """
-        self._back_haul_subnet_mask = value
-
-    
     @property
     def back_haul_vnid(self):
         """ Get back_haul_vnid value.
@@ -1231,33 +1051,6 @@ class NUDomain(NURESTObject):
         self._policy_change_status = value
 
     
-    @property
-    def domain_id(self):
-        """ Get domain_id value.
-
-            Notes:
-                A unique 20-bitID editable however could be auto-generated by VSD.
-
-                
-                This attribute is named `domainID` in VSD API.
-                
-        """
-        return self._domain_id
-
-    @domain_id.setter
-    def domain_id(self, value):
-        """ Set domain_id value.
-
-            Notes:
-                A unique 20-bitID editable however could be auto-generated by VSD.
-
-                
-                This attribute is named `domainID` in VSD API.
-                
-        """
-        self._domain_id = value
-
-    
     @property
     def route_distinguisher(self):
         """ Get route_distinguisher value.
@@ -1366,33 +1159,6 @@ class NUDomain(NURESTObject):
         self._application_deployment_policy = value
 
     
-    @property
-    def associated_bgp_profile_id(self):
-        """ Get associated_bgp_profile_id value.
-
-            Notes:
-                None
-
-                
-                This attribute is named `associatedBGPProfileID` in VSD API.
-                
-        """
-        return self._associated_bgp_profile_id
-
-    @associated_bgp_profile_id.setter
-    def associated_bgp_profile_id(self, value):
-        """ Set associated_bgp_profile_id value.
-
-            Notes:
-                None
-
-                
-                This attribute is named `associatedBGPProfileID` in VSD API.
-                
-        """
-        self._associated_bgp_profile_id = value
-
-    
     @property
     def associated_multicast_channel_map_id(self):
         """ Get associated_multicast_channel_map_id value.
@@ -1420,33 +1186,6 @@ class NUDomain(NURESTObject):
         self._associated_multicast_channel_map_id = value
 
     
-    @property
-    def associated_pat_mapper_id(self):
-        """ Get associated_pat_mapper_id value.
-
-            Notes:
-                The ID of the PatMapper entity to which this l3-domain is associated to.
-
-                
-                This attribute is named `associatedPATMapperID` in VSD API.
-                
-        """
-        return self._associated_pat_mapper_id
-
-    @associated_pat_mapper_id.setter
-    def associated_pat_mapper_id(self, value):
-        """ Set associated_pat_mapper_id value.
-
-            Notes:
-                The ID of the PatMapper entity to which this l3-domain is associated to.
-
-                
-                This attribute is named `associatedPATMapperID` in VSD API.
-                
-        """
-        self._associated_pat_mapper_id = value
-
-    
     @property
     def stretched(self):
         """ Get stretched value.
