@@ -42,9 +42,6 @@ from .fetchers import NUGatewaysFetcher
 from .fetchers import NUGatewayTemplatesFetcher
 
 
-from .fetchers import NUPATMappersFetcher
-
-
 from .fetchers import NUPATNATPoolsFetcher
 
 
@@ -75,33 +72,12 @@ from .fetchers import NUMetadataTagsFetcher
 from .fetchers import NUNetworkLayoutsFetcher
 
 
-from .fetchers import NUKeyServerMembersFetcher
-
-
-from .fetchers import NUZFBAutoAssignmentsFetcher
-
-
-from .fetchers import NUZFBRequestsFetcher
-
-
-from .fetchers import NUBGPNeighborsFetcher
-
-
-from .fetchers import NUBGPProfilesFetcher
-
-
 from .fetchers import NUEgressACLEntryTemplatesFetcher
 
 
 from .fetchers import NUEgressACLTemplatesFetcher
 
 
-from .fetchers import NUDomainFIPAclTemplatesFetcher
-
-
-from .fetchers import NUFloatingIPACLTemplatesFetcher
-
-
 from .fetchers import NUEgressQOSPoliciesFetcher
 
 
@@ -111,9 +87,6 @@ from .fetchers import NUSharedNetworkResourcesFetcher
 from .fetchers import NULicensesFetcher
 
 
-from .fetchers import NULicenseStatusFetcher
-
-
 from .fetchers import NUMirrorDestinationsFetcher
 
 
@@ -138,6 +111,9 @@ from .fetchers import NUCloudMgmtSystemsFetcher
 from .fetchers import NUInfrastructureGatewayProfilesFetcher
 
 
+from .fetchers import NUInfrastructurePortProfilesFetcher
+
+
 from .fetchers import NUInfrastructureVscProfilesFetcher
 
 
@@ -168,18 +144,9 @@ from .fetchers import NUDomainsFetcher
 from .fetchers import NUZonesFetcher
 
 
-from .fetchers import NUContainersFetcher
-
-
-from .fetchers import NUContainerInterfacesFetcher
-
-
 from .fetchers import NUHostInterfacesFetcher
 
 
-from .fetchers import NURoutingPoliciesFetcher
-
-
 from .fetchers import NUUplinkRDsFetcher
 
 
@@ -204,6 +171,9 @@ from .fetchers import NUNSRedundantGatewayGroupsFetcher
 from .fetchers import NUVSPsFetcher
 
 
+from .fetchers import NUNSPortStaticConfigurationsFetcher
+
+
 from .fetchers import NUStaticRoutesFetcher
 
 
@@ -277,7 +247,6 @@ class NUMe(NURESTRootObject):
         self._last_updated_by = None
         self._first_name = None
         self._disabled = None
-        self._elastic_search_ui_address = None
         self._email = None
         self._enterprise_id = None
         self._enterprise_name = None
@@ -294,7 +263,6 @@ class NUMe(NURESTRootObject):
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="first_name", remote_name="firstName", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="disabled", remote_name="disabled", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="elastic_search_ui_address", remote_name="elasticSearchUIAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="email", remote_name="email", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="enterprise_id", remote_name="enterpriseID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="enterprise_name", remote_name="enterpriseName", attribute_type=str, is_required=False, is_unique=False)
@@ -325,9 +293,6 @@ class NUMe(NURESTRootObject):
         self.gateway_templates = NUGatewayTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.pat_mappers = NUPATMappersFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.patnat_pools = NUPATNATPoolsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -358,33 +323,12 @@ class NUMe(NURESTRootObject):
         self.network_layouts = NUNetworkLayoutsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.key_server_members = NUKeyServerMembersFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
-        self.zfb_auto_assignments = NUZFBAutoAssignmentsFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
-        self.zfb_requests = NUZFBRequestsFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
-        self.bgp_neighbors = NUBGPNeighborsFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
-        self.bgp_profiles = NUBGPProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.egress_acl_entry_templates = NUEgressACLEntryTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
         self.egress_acl_templates = NUEgressACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.domain_fip_acl_templates = NUDomainFIPAclTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
-        self.floating_ipacl_templates = NUFloatingIPACLTemplatesFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.egress_qos_policies = NUEgressQOSPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -394,9 +338,6 @@ class NUMe(NURESTRootObject):
         self.licenses = NULicensesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.license_status = NULicenseStatusFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.mirror_destinations = NUMirrorDestinationsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -421,6 +362,9 @@ class NUMe(NURESTRootObject):
         self.infrastructure_gateway_profiles = NUInfrastructureGatewayProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.infrastructure_port_profiles = NUInfrastructurePortProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.infrastructure_vsc_profiles = NUInfrastructureVscProfilesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -451,18 +395,9 @@ class NUMe(NURESTRootObject):
         self.zones = NUZonesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.containers = NUContainersFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
-        self.container_interfaces = NUContainerInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.host_interfaces = NUHostInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
-        self.routing_policies = NURoutingPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="root")
-        
-        
         self.uplink_rds = NUUplinkRDsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -487,6 +422,9 @@ class NUMe(NURESTRootObject):
         self.vsps = NUVSPsFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
+        self.ns_port_static_configurations = NUNSPortStaticConfigurationsFetcher.fetcher_with_object(parent_object=self, relationship="root")
+        
+        
         self.static_routes = NUStaticRoutesFetcher.fetcher_with_object(parent_object=self, relationship="root")
         
         
@@ -642,33 +580,6 @@ class NUMe(NURESTRootObject):
         self._disabled = value
 
     
-    @property
-    def elastic_search_ui_address(self):
-        """ Get elastic_search_ui_address value.
-
-            Notes:
-                elastic search UI address
-
-                
-                This attribute is named `elasticSearchUIAddress` in VSD API.
-                
-        """
-        return self._elastic_search_ui_address
-
-    @elastic_search_ui_address.setter
-    def elastic_search_ui_address(self, value):
-        """ Set elastic_search_ui_address value.
-
-            Notes:
-                elastic search UI address
-
-                
-                This attribute is named `elasticSearchUIAddress` in VSD API.
-                
-        """
-        self._elastic_search_ui_address = value
-
-    
     @property
     def email(self):
         """ Get email value.
@@ -932,4 +843,10 @@ class NUMe(NURESTRootObject):
 
     
 
+    
+    ## Custom methods
+    def save(self, async=False, callback=None):
+        """ """
+        super(NUMe, self).save(async=async, callback=callback, encrypted=False)
+    
     
\ No newline at end of file
