@@ -27,12 +27,6 @@
 
 
 
-from .fetchers import NUGatewaySecuritiesFetcher
-
-
-from .fetchers import NUGatewaySecurityProfilesFetcher
-
-
 from .fetchers import NUPATNATPoolsFetcher
 
 
@@ -210,12 +204,6 @@ class NUNSGateway(NURESTObject):
         # Fetchers
         
         
-        self.gateway_securities = NUGatewaySecuritiesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.gateway_security_profiles = NUGatewaySecurityProfilesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.patnat_pools = NUPATNATPoolsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
