@@ -45,10 +45,7 @@ from .fetchers import NUGlobalMetadatasFetcher
 from .fetchers import NUEnterprisePermissionsFetcher
 
 
-from .fetchers import NUStatisticsFetcher
-
-
-from .fetchers import NUStatisticsPoliciesFetcher
+from .fetchers import NUNSPortStaticConfigurationsFetcher
 
 
 from .fetchers import NUEventLogsFetcher
@@ -60,7 +57,7 @@ class NUNSPort(NURESTObject):
     """ Represents a NSPort in the VSD
 
         Notes:
-            Represents a Port of a particular NS Gateway object.
+            Represents a Port of a particular NS gateway object.
     """
 
     __rest_name__ = "nsport"
@@ -69,49 +66,33 @@ class NUNSPort(NURESTObject):
     
     ## Constants
     
-    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
-    
-    CONST_SPEED_BASE10 = "BASE10"
-    
-    CONST_SPEED_BASETX100 = "BASETX100"
-    
-    CONST_PERMITTED_ACTION_EXTEND = "EXTEND"
-    
-    CONST_PORT_TYPE_ACCESS = "ACCESS"
-    
-    CONST_PERMITTED_ACTION_INSTANTIATE = "INSTANTIATE"
-    
-    CONST_SPEED_BASET1000 = "BASET1000"
-    
-    CONST_STATUS_INITIALIZED = "INITIALIZED"
-    
-    CONST_SPEED_BASEX10G = "BASEX10G"
-    
     CONST_PORT_TYPE_NETWORK = "NETWORK"
     
-    CONST_NAT_TRAVERSAL_FULL_NAT = "FULL_NAT"
-    
-    CONST_PERMITTED_ACTION_READ = "READ"
-    
     CONST_PERMITTED_ACTION_USE = "USE"
     
-    CONST_NAT_TRAVERSAL_NONE = "NONE"
+    CONST_PERMITTED_ACTION_READ = "READ"
     
-    CONST_STATUS_MISMATCH = "MISMATCH"
-    
-    CONST_STATUS_ORPHAN = "ORPHAN"
-    
-    CONST_SPEED_AUTONEGOTIATE = "AUTONEGOTIATE"
-    
-    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
-    
-    CONST_NAT_TRAVERSAL_ONE_TO_ONE_NAT = "ONE_TO_ONE_NAT"
+    CONST_STATUS_READY = "READY"
     
     CONST_PERMITTED_ACTION_ALL = "ALL"
     
     CONST_PERMITTED_ACTION_DEPLOY = "DEPLOY"
     
-    CONST_STATUS_READY = "READY"
+    CONST_PERMITTED_ACTION_EXTEND = "EXTEND"
+    
+    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    
+    CONST_PERMITTED_ACTION_INSTANTIATE = "INSTANTIATE"
+    
+    CONST_STATUS_INITIALIZED = "INITIALIZED"
+    
+    CONST_STATUS_MISMATCH = "MISMATCH"
+    
+    CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
+    
+    CONST_PORT_TYPE_ACCESS = "ACCESS"
+    
+    CONST_STATUS_ORPHAN = "ORPHAN"
     
     
 
@@ -132,7 +113,6 @@ class NUNSPort(NURESTObject):
 
         # Read/Write Attributes
         
-        self._nat_traversal = None
         self._vlan_range = None
         self._name = None
         self._last_updated_by = None
@@ -140,18 +120,17 @@ class NUNSPort(NURESTObject):
         self._permitted_action = None
         self._description = None
         self._physical_name = None
+        self._infrastructure_profile_id = None
         self._entity_scope = None
         self._port_type = None
-        self._speed = None
         self._use_user_mnemonic = None
         self._user_mnemonic = None
         self._associated_egress_qos_policy_id = None
         self._associated_redundant_port_id = None
+        self._associated_vsc_profile_id = None
         self._status = None
-        self._mtu = None
         self._external_id = None
         
-        self.expose_attribute(local_name="nat_traversal", remote_name="NATTraversal", attribute_type=str, is_required=False, is_unique=False, choices=[u'FULL_NAT', u'NONE', u'ONE_TO_ONE_NAT'])
         self.expose_attribute(local_name="vlan_range", remote_name="VLANRange", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
@@ -159,15 +138,15 @@ class NUNSPort(NURESTObject):
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="physical_name", remote_name="physicalName", attribute_type=str, is_required=True, is_unique=False)
+        self.expose_attribute(local_name="infrastructure_profile_id", remote_name="infrastructureProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="port_type", remote_name="portType", attribute_type=str, is_required=True, is_unique=False, choices=[u'ACCESS', u'NETWORK'])
-        self.expose_attribute(local_name="speed", remote_name="speed", attribute_type=str, is_required=False, is_unique=False, choices=[u'AUTONEGOTIATE', u'BASE10', u'BASET1000', u'BASETX100', u'BASEX10G'])
         self.expose_attribute(local_name="use_user_mnemonic", remote_name="useUserMnemonic", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="user_mnemonic", remote_name="userMnemonic", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="associated_egress_qos_policy_id", remote_name="associatedEgressQOSPolicyID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="associated_redundant_port_id", remote_name="associatedRedundantPortID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_vsc_profile_id", remote_name="associatedVSCProfileID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="status", remote_name="status", attribute_type=str, is_required=False, is_unique=False, choices=[u'INITIALIZED', u'MISMATCH', u'ORPHAN', u'READY'])
-        self.expose_attribute(local_name="mtu", remote_name="mtu", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -192,10 +171,7 @@ class NUNSPort(NURESTObject):
         self.enterprise_permissions = NUEnterprisePermissionsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.statistics = NUStatisticsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.statistics_policies = NUStatisticsPoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
+        self.ns_port_static_configurations = NUNSPortStaticConfigurationsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self, relationship="child")
@@ -205,33 +181,6 @@ class NUNSPort(NURESTObject):
 
     # Properties
     
-    @property
-    def nat_traversal(self):
-        """ Get nat_traversal value.
-
-            Notes:
-                Enum value that states the type of NAT Traversal the NSG instance will use to talk to other NSGs and the Internet.
-
-                
-                This attribute is named `NATTraversal` in VSD API.
-                
-        """
-        return self._nat_traversal
-
-    @nat_traversal.setter
-    def nat_traversal(self, value):
-        """ Set nat_traversal value.
-
-            Notes:
-                Enum value that states the type of NAT Traversal the NSG instance will use to talk to other NSGs and the Internet.
-
-                
-                This attribute is named `NATTraversal` in VSD API.
-                
-        """
-        self._nat_traversal = value
-
-    
     @property
     def vlan_range(self):
         """ Get vlan_range value.
@@ -413,6 +362,33 @@ class NUNSPort(NURESTObject):
         self._physical_name = value
 
     
+    @property
+    def infrastructure_profile_id(self):
+        """ Get infrastructure_profile_id value.
+
+            Notes:
+                The ID of the infrastructure profile this instance is associated with.
+
+                
+                This attribute is named `infrastructureProfileID` in VSD API.
+                
+        """
+        return self._infrastructure_profile_id
+
+    @infrastructure_profile_id.setter
+    def infrastructure_profile_id(self, value):
+        """ Set infrastructure_profile_id value.
+
+            Notes:
+                The ID of the infrastructure profile this instance is associated with.
+
+                
+                This attribute is named `infrastructureProfileID` in VSD API.
+                
+        """
+        self._infrastructure_profile_id = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -467,29 +443,6 @@ class NUNSPort(NURESTObject):
         self._port_type = value
 
     
-    @property
-    def speed(self):
-        """ Get speed value.
-
-            Notes:
-                Port Speed in Mb/s :  Supported Ethernet speeds are 10 (10Base-T), 100 (Fast-ethernet 100Base-TX), 1000 (Gigabit Ethernet 1000Base-T), 10 000 (10 Gigabit Ethernet 10GBase-X), and Auto-Negotiate.
-
-                
-        """
-        return self._speed
-
-    @speed.setter
-    def speed(self, value):
-        """ Set speed value.
-
-            Notes:
-                Port Speed in Mb/s :  Supported Ethernet speeds are 10 (10Base-T), 100 (Fast-ethernet 100Base-TX), 1000 (Gigabit Ethernet 1000Base-T), 10 000 (10 Gigabit Ethernet 10GBase-X), and Auto-Negotiate.
-
-                
-        """
-        self._speed = value
-
-    
     @property
     def use_user_mnemonic(self):
         """ Get use_user_mnemonic value.
@@ -598,6 +551,33 @@ class NUNSPort(NURESTObject):
         self._associated_redundant_port_id = value
 
     
+    @property
+    def associated_vsc_profile_id(self):
+        """ Get associated_vsc_profile_id value.
+
+            Notes:
+                The ID of the infrastructure VSC profile this is associated with this instance of a port or port template.
+
+                
+                This attribute is named `associatedVSCProfileID` in VSD API.
+                
+        """
+        return self._associated_vsc_profile_id
+
+    @associated_vsc_profile_id.setter
+    def associated_vsc_profile_id(self, value):
+        """ Set associated_vsc_profile_id value.
+
+            Notes:
+                The ID of the infrastructure VSC profile this is associated with this instance of a port or port template.
+
+                
+                This attribute is named `associatedVSCProfileID` in VSD API.
+                
+        """
+        self._associated_vsc_profile_id = value
+
+    
     @property
     def status(self):
         """ Get status value.
@@ -621,29 +601,6 @@ class NUNSPort(NURESTObject):
         self._status = value
 
     
-    @property
-    def mtu(self):
-        """ Get mtu value.
-
-            Notes:
-                Port MTU (Maximum Transmission Unit) :  The size in octets of the largest protocol data unit (PDU) that the layer can pass on.  The default value is normally 1500 octets for Ethernet v2 and can go up to 9198 for Jumbo Frames.
-
-                
-        """
-        return self._mtu
-
-    @mtu.setter
-    def mtu(self, value):
-        """ Set mtu value.
-
-            Notes:
-                Port MTU (Maximum Transmission Unit) :  The size in octets of the largest protocol data unit (PDU) that the layer can pass on.  The default value is normally 1500 octets for Ethernet v2 and can go up to 9198 for Jumbo Frames.
-
-                
-        """
-        self._mtu = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
