@@ -54,9 +54,6 @@ from .fetchers import NUPortsFetcher
 from .fetchers import NUVsgRedundantPortsFetcher
 
 
-from .fetchers import NUVsgRedundantPortsFetcher
-
-
 from .fetchers import NUEventLogsFetcher
 
 from bambou import NURESTObject
@@ -134,6 +131,7 @@ class NURedundancyGroup(NURESTObject):
         self._gateway_peer1_id = None
         self._gateway_peer1_name = None
         self._gateway_peer2_autodiscovered_gateway_id = None
+        self._gateway_peer2_id = None
         self._gateway_peer2_name = None
         self._redundant_gateway_status = None
         self._permitted_action = None
@@ -150,6 +148,7 @@ class NURedundancyGroup(NURESTObject):
         self.expose_attribute(local_name="gateway_peer1_id", remote_name="gatewayPeer1ID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway_peer1_name", remote_name="gatewayPeer1Name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway_peer2_autodiscovered_gateway_id", remote_name="gatewayPeer2AutodiscoveredGatewayID", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="gateway_peer2_id", remote_name="gatewayPeer2ID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="gateway_peer2_name", remote_name="gatewayPeer2Name", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="redundant_gateway_status", remote_name="redundantGatewayStatus", attribute_type=str, is_required=False, is_unique=False, choices=[u'FAILED', u'SUCCESS'])
         self.expose_attribute(local_name="permitted_action", remote_name="permittedAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'ALL', u'DEPLOY', u'EXTEND', u'INSTANTIATE', u'READ', u'USE'])
@@ -191,9 +190,6 @@ class NURedundancyGroup(NURESTObject):
         self.vsg_redundant_ports = NUVsgRedundantPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.vsg_redundant_ports = NUVsgRedundantPortsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.event_logs = NUEventLogsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
 
@@ -359,6 +355,33 @@ class NURedundancyGroup(NURESTObject):
         self._gateway_peer2_autodiscovered_gateway_id = value
 
     
+    @property
+    def gateway_peer2_id(self):
+        """ Get gateway_peer2_id value.
+
+            Notes:
+                The gateway configuration owner in this Redundant Group. when Redundant Group is deleted this gateway will recieve vport associations 
+
+                
+                This attribute is named `gatewayPeer2ID` in VSD API.
+                
+        """
+        return self._gateway_peer2_id
+
+    @gateway_peer2_id.setter
+    def gateway_peer2_id(self, value):
+        """ Set gateway_peer2_id value.
+
+            Notes:
+                The gateway configuration owner in this Redundant Group. when Redundant Group is deleted this gateway will recieve vport associations 
+
+                
+                This attribute is named `gatewayPeer2ID` in VSD API.
+                
+        """
+        self._gateway_peer2_id = value
+
+    
     @property
     def gateway_peer2_name(self):
         """ Get gateway_peer2_name value.
