@@ -36,17 +36,8 @@ from .fetchers import NUMetadatasFetcher
 from .fetchers import NUGlobalMetadatasFetcher
 
 
-from .fetchers import NUJobsFetcher
-
-
 from .fetchers import NUVRSAddressRangesFetcher
 
-
-from .fetchers import NUVRSRedeploymentpoliciesFetcher
-
-
-from .fetchers import NUAutodiscovereddatacentersFetcher
-
 from bambou import NURESTObject
 
 
@@ -96,7 +87,6 @@ class NUVCenter(NURESTObject):
         self._data_network_portgroup = None
         self._datapath_sync_timeout = None
         self._secondary_nuage_controller = None
-        self._generic_split_activation = None
         self._separate_data_network = None
         self._personality = None
         self._description = None
@@ -121,7 +111,6 @@ class NUVCenter(NURESTObject):
         self._flow_eviction_threshold = None
         self._vm_network_portgroup = None
         self._entity_scope = None
-        self._connection_status = None
         self._portgroup_metadata = None
         self._host_level_management = None
         self._nova_client_version = None
@@ -170,7 +159,6 @@ class NUVCenter(NURESTObject):
         self.expose_attribute(local_name="data_network_portgroup", remote_name="dataNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="datapath_sync_timeout", remote_name="datapathSyncTimeout", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="secondary_nuage_controller", remote_name="secondaryNuageController", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="generic_split_activation", remote_name="genericSplitActivation", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="separate_data_network", remote_name="separateDataNetwork", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
@@ -195,7 +183,6 @@ class NUVCenter(NURESTObject):
         self.expose_attribute(local_name="flow_eviction_threshold", remote_name="flowEvictionThreshold", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vm_network_portgroup", remote_name="vmNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
-        self.expose_attribute(local_name="connection_status", remote_name="connectionStatus", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="portgroup_metadata", remote_name="portgroupMetadata", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="host_level_management", remote_name="hostLevelManagement", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="nova_client_version", remote_name="novaClientVersion", attribute_type=int, is_required=False, is_unique=False)
@@ -247,17 +234,8 @@ class NUVCenter(NURESTObject):
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.vrs_address_ranges = NUVRSAddressRangesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
-        
-        self.vrs_redeploymentpolicies = NUVRSRedeploymentpoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.autodiscovereddatacenters = NUAutodiscovereddatacentersFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
 
         self._compute_args(**kwargs)
 
@@ -525,33 +503,6 @@ class NUVCenter(NURESTObject):
         self._secondary_nuage_controller = value
 
     
-    @property
-    def generic_split_activation(self):
-        """ Get generic_split_activation value.
-
-            Notes:
-                Whether split-activation is needed from VRO
-
-                
-                This attribute is named `genericSplitActivation` in VSD API.
-                
-        """
-        return self._generic_split_activation
-
-    @generic_split_activation.setter
-    def generic_split_activation(self, value):
-        """ Set generic_split_activation value.
-
-            Notes:
-                Whether split-activation is needed from VRO
-
-                
-                This attribute is named `genericSplitActivation` in VSD API.
-                
-        """
-        self._generic_split_activation = value
-
-    
     @property
     def separate_data_network(self):
         """ Get separate_data_network value.
@@ -1192,33 +1143,6 @@ class NUVCenter(NURESTObject):
         self._entity_scope = value
 
     
-    @property
-    def connection_status(self):
-        """ Get connection_status value.
-
-            Notes:
-                VCenter connection status.
-
-                
-                This attribute is named `connectionStatus` in VSD API.
-                
-        """
-        return self._connection_status
-
-    @connection_status.setter
-    def connection_status(self, value):
-        """ Set connection_status value.
-
-            Notes:
-                VCenter connection status.
-
-                
-                This attribute is named `connectionStatus` in VSD API.
-                
-        """
-        self._connection_status = value
-
-    
     @property
     def portgroup_metadata(self):
         """ Get portgroup_metadata value.
