@@ -36,17 +36,8 @@ from .fetchers import NUMetadatasFetcher
 from .fetchers import NUGlobalMetadatasFetcher
 
 
-from .fetchers import NUJobsFetcher
-
-
 from .fetchers import NUVRSAddressRangesFetcher
 
-
-from .fetchers import NUVRSRedeploymentpoliciesFetcher
-
-
-from .fetchers import NUAutoDiscoverHypervisorFromClustersFetcher
-
 from bambou import NURESTObject
 
 
@@ -88,16 +79,13 @@ class NUVCenterCluster(NURESTObject):
         
         self._v_require_nuage_metadata = None
         self._name = None
-        self._managed_object_id = None
         self._last_updated_by = None
         self._data_dns1 = None
         self._data_dns2 = None
         self._data_gateway = None
         self._data_network_portgroup = None
         self._datapath_sync_timeout = None
-        self._scope = None
         self._secondary_nuage_controller = None
-        self._generic_split_activation = None
         self._separate_data_network = None
         self._personality = None
         self._description = None
@@ -135,7 +123,6 @@ class NUVCenterCluster(NURESTObject):
         self._vrs_password = None
         self._vrs_user_name = None
         self._assoc_vcenter_data_center_id = None
-        self._assoc_vcenter_id = None
         self._static_route = None
         self._static_route_gateway = None
         self._static_route_netmask = None
@@ -156,16 +143,13 @@ class NUVCenterCluster(NURESTObject):
         
         self.expose_attribute(local_name="v_require_nuage_metadata", remote_name="vRequireNuageMetadata", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
-        self.expose_attribute(local_name="managed_object_id", remote_name="managedObjectID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_dns1", remote_name="dataDNS1", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_dns2", remote_name="dataDNS2", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_gateway", remote_name="dataGateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_network_portgroup", remote_name="dataNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="datapath_sync_timeout", remote_name="datapathSyncTimeout", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="scope", remote_name="scope", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="secondary_nuage_controller", remote_name="secondaryNuageController", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="generic_split_activation", remote_name="genericSplitActivation", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="separate_data_network", remote_name="separateDataNetwork", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
@@ -203,7 +187,6 @@ class NUVCenterCluster(NURESTObject):
         self.expose_attribute(local_name="vrs_password", remote_name="vrsPassword", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vrs_user_name", remote_name="vrsUserName", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="assoc_vcenter_data_center_id", remote_name="assocVCenterDataCenterID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="assoc_vcenter_id", remote_name="assocVCenterID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="static_route", remote_name="staticRoute", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="static_route_gateway", remote_name="staticRouteGateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="static_route_netmask", remote_name="staticRouteNetmask", attribute_type=str, is_required=False, is_unique=False)
@@ -235,17 +218,8 @@ class NUVCenterCluster(NURESTObject):
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.jobs = NUJobsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.vrs_address_ranges = NUVRSAddressRangesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
-        
-        self.vrs_redeploymentpolicies = NUVRSRedeploymentpoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.auto_discover_hypervisor_from_clusters = NUAutoDiscoverHypervisorFromClustersFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
 
         self._compute_args(**kwargs)
 
@@ -301,33 +275,6 @@ class NUVCenterCluster(NURESTObject):
         self._name = value
 
     
-    @property
-    def managed_object_id(self):
-        """ Get managed_object_id value.
-
-            Notes:
-                VCenter Managed Object ID of the Cluster.
-
-                
-                This attribute is named `managedObjectID` in VSD API.
-                
-        """
-        return self._managed_object_id
-
-    @managed_object_id.setter
-    def managed_object_id(self, value):
-        """ Set managed_object_id value.
-
-            Notes:
-                VCenter Managed Object ID of the Cluster.
-
-                
-                This attribute is named `managedObjectID` in VSD API.
-                
-        """
-        self._managed_object_id = value
-
-    
     @property
     def last_updated_by(self):
         """ Get last_updated_by value.
@@ -490,29 +437,6 @@ class NUVCenterCluster(NURESTObject):
         self._datapath_sync_timeout = value
 
     
-    @property
-    def scope(self):
-        """ Get scope value.
-
-            Notes:
-                Cluster in scope or not in scope.
-
-                
-        """
-        return self._scope
-
-    @scope.setter
-    def scope(self, value):
-        """ Set scope value.
-
-            Notes:
-                Cluster in scope or not in scope.
-
-                
-        """
-        self._scope = value
-
-    
     @property
     def secondary_nuage_controller(self):
         """ Get secondary_nuage_controller value.
@@ -540,33 +464,6 @@ class NUVCenterCluster(NURESTObject):
         self._secondary_nuage_controller = value
 
     
-    @property
-    def generic_split_activation(self):
-        """ Get generic_split_activation value.
-
-            Notes:
-                Whether split-activation is needed from VRO
-
-                
-                This attribute is named `genericSplitActivation` in VSD API.
-                
-        """
-        return self._generic_split_activation
-
-    @generic_split_activation.setter
-    def generic_split_activation(self, value):
-        """ Set generic_split_activation value.
-
-            Notes:
-                Whether split-activation is needed from VRO
-
-                
-                This attribute is named `genericSplitActivation` in VSD API.
-                
-        """
-        self._generic_split_activation = value
-
-    
     @property
     def separate_data_network(self):
         """ Get separate_data_network value.
@@ -1558,33 +1455,6 @@ class NUVCenterCluster(NURESTObject):
         self._assoc_vcenter_data_center_id = value
 
     
-    @property
-    def assoc_vcenter_id(self):
-        """ Get assoc_vcenter_id value.
-
-            Notes:
-                ID of the associated VCenter.
-
-                
-                This attribute is named `assocVCenterID` in VSD API.
-                
-        """
-        return self._assoc_vcenter_id
-
-    @assoc_vcenter_id.setter
-    def assoc_vcenter_id(self, value):
-        """ Set assoc_vcenter_id value.
-
-            Notes:
-                ID of the associated VCenter.
-
-                
-                This attribute is named `assocVCenterID` in VSD API.
-                
-        """
-        self._assoc_vcenter_id = value
-
-    
     @property
     def static_route(self):
         """ Get static_route value.
