@@ -38,12 +38,6 @@ from .fetchers import NUJobsFetcher
 
 from .fetchers import NUVRSAddressRangesFetcher
 
-
-from .fetchers import NUVRSMetricsFetcher
-
-
-from .fetchers import NUVRSRedeploymentpoliciesFetcher
-
 from bambou import NURESTObject
 
 
@@ -86,11 +80,9 @@ class NUVCenterHypervisor(NURESTObject):
         self._vcenter_ip = None
         self._vcenter_password = None
         self._vcenter_user = None
-        self._vrs_metrics_id = None
         self._v_require_nuage_metadata = None
         self._name = None
         self._last_updated_by = None
-        self._last_vrs_deployed_date = None
         self._data_dns1 = None
         self._data_dns2 = None
         self._data_gateway = None
@@ -98,11 +90,8 @@ class NUVCenterHypervisor(NURESTObject):
         self._data_netmask = None
         self._data_network_portgroup = None
         self._datapath_sync_timeout = None
-        self._scope = None
         self._secondary_nuage_controller = None
-        self._generic_split_activation = None
         self._separate_data_network = None
-        self._deployment_count = None
         self._personality = None
         self._description = None
         self._metadata_server_ip = None
@@ -146,6 +135,7 @@ class NUVCenterHypervisor(NURESTObject):
         self._vrs_id = None
         self._vrs_password = None
         self._vrs_user_name = None
+        self._associated_cluster_id = None
         self._static_route = None
         self._static_route_gateway = None
         self._static_route_netmask = None
@@ -162,7 +152,6 @@ class NUVCenterHypervisor(NURESTObject):
         self._multicast_send_interface_netmask = None
         self._multicast_source_portgroup = None
         self._customized_script_url = None
-        self._available_networks = None
         self._external_id = None
         self._hypervisor_ip = None
         self._hypervisor_password = None
@@ -171,11 +160,9 @@ class NUVCenterHypervisor(NURESTObject):
         self.expose_attribute(local_name="vcenter_ip", remote_name="vCenterIP", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vcenter_password", remote_name="vCenterPassword", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vcenter_user", remote_name="vCenterUser", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="vrs_metrics_id", remote_name="VRSMetricsID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="v_require_nuage_metadata", remote_name="vRequireNuageMetadata", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="last_vrs_deployed_date", remote_name="lastVRSDeployedDate", attribute_type=float, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_dns1", remote_name="dataDNS1", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_dns2", remote_name="dataDNS2", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_gateway", remote_name="dataGateway", attribute_type=str, is_required=False, is_unique=False)
@@ -183,11 +170,8 @@ class NUVCenterHypervisor(NURESTObject):
         self.expose_attribute(local_name="data_netmask", remote_name="dataNetmask", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_network_portgroup", remote_name="dataNetworkPortgroup", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="datapath_sync_timeout", remote_name="datapathSyncTimeout", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="scope", remote_name="scope", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="secondary_nuage_controller", remote_name="secondaryNuageController", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="generic_split_activation", remote_name="genericSplitActivation", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="separate_data_network", remote_name="separateDataNetwork", attribute_type=bool, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="deployment_count", remote_name="deploymentCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="metadata_server_ip", remote_name="metadataServerIP", attribute_type=str, is_required=False, is_unique=False)
@@ -231,6 +215,7 @@ class NUVCenterHypervisor(NURESTObject):
         self.expose_attribute(local_name="vrs_id", remote_name="vrsId", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vrs_password", remote_name="vrsPassword", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="vrs_user_name", remote_name="vrsUserName", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="associated_cluster_id", remote_name="associatedClusterID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="static_route", remote_name="staticRoute", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="static_route_gateway", remote_name="staticRouteGateway", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="static_route_netmask", remote_name="staticRouteNetmask", attribute_type=str, is_required=False, is_unique=False)
@@ -247,7 +232,6 @@ class NUVCenterHypervisor(NURESTObject):
         self.expose_attribute(local_name="multicast_send_interface_netmask", remote_name="multicastSendInterfaceNetmask", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast_source_portgroup", remote_name="multicastSourcePortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="customized_script_url", remote_name="customizedScriptURL", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="available_networks", remote_name="availableNetworks", attribute_type=list, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         self.expose_attribute(local_name="hypervisor_ip", remote_name="hypervisorIP", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="hypervisor_password", remote_name="hypervisorPassword", attribute_type=str, is_required=True, is_unique=False)
@@ -268,12 +252,6 @@ class NUVCenterHypervisor(NURESTObject):
         
         self.vrs_address_ranges = NUVRSAddressRangesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
-        
-        self.vrs_metrics = NUVRSMetricsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.vrs_redeploymentpolicies = NUVRSRedeploymentpoliciesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
 
         self._compute_args(**kwargs)
 
@@ -360,33 +338,6 @@ class NUVCenterHypervisor(NURESTObject):
         self._vcenter_user = value
 
     
-    @property
-    def vrs_metrics_id(self):
-        """ Get vrs_metrics_id value.
-
-            Notes:
-                ID of the VRS metrics object.
-
-                
-                This attribute is named `VRSMetricsID` in VSD API.
-                
-        """
-        return self._vrs_metrics_id
-
-    @vrs_metrics_id.setter
-    def vrs_metrics_id(self, value):
-        """ Set vrs_metrics_id value.
-
-            Notes:
-                ID of the VRS metrics object.
-
-                
-                This attribute is named `VRSMetricsID` in VSD API.
-                
-        """
-        self._vrs_metrics_id = value
-
-    
     @property
     def v_require_nuage_metadata(self):
         """ Get v_require_nuage_metadata value.
@@ -464,33 +415,6 @@ class NUVCenterHypervisor(NURESTObject):
         self._last_updated_by = value
 
     
-    @property
-    def last_vrs_deployed_date(self):
-        """ Get last_vrs_deployed_date value.
-
-            Notes:
-                Determines the time the vrs vm was last deployed.
-
-                
-                This attribute is named `lastVRSDeployedDate` in VSD API.
-                
-        """
-        return self._last_vrs_deployed_date
-
-    @last_vrs_deployed_date.setter
-    def last_vrs_deployed_date(self, value):
-        """ Set last_vrs_deployed_date value.
-
-            Notes:
-                Determines the time the vrs vm was last deployed.
-
-                
-                This attribute is named `lastVRSDeployedDate` in VSD API.
-                
-        """
-        self._last_vrs_deployed_date = value
-
-    
     @property
     def data_dns1(self):
         """ Get data_dns1 value.
@@ -680,29 +604,6 @@ class NUVCenterHypervisor(NURESTObject):
         self._datapath_sync_timeout = value
 
     
-    @property
-    def scope(self):
-        """ Get scope value.
-
-            Notes:
-                Cluster in scope or not in scope.
-
-                
-        """
-        return self._scope
-
-    @scope.setter
-    def scope(self, value):
-        """ Set scope value.
-
-            Notes:
-                Cluster in scope or not in scope.
-
-                
-        """
-        self._scope = value
-
-    
     @property
     def secondary_nuage_controller(self):
         """ Get secondary_nuage_controller value.
@@ -730,33 +631,6 @@ class NUVCenterHypervisor(NURESTObject):
         self._secondary_nuage_controller = value
 
     
-    @property
-    def generic_split_activation(self):
-        """ Get generic_split_activation value.
-
-            Notes:
-                Whether split-activation is needed from VRO
-
-                
-                This attribute is named `genericSplitActivation` in VSD API.
-                
-        """
-        return self._generic_split_activation
-
-    @generic_split_activation.setter
-    def generic_split_activation(self, value):
-        """ Set generic_split_activation value.
-
-            Notes:
-                Whether split-activation is needed from VRO
-
-                
-                This attribute is named `genericSplitActivation` in VSD API.
-                
-        """
-        self._generic_split_activation = value
-
-    
     @property
     def separate_data_network(self):
         """ Get separate_data_network value.
@@ -784,33 +658,6 @@ class NUVCenterHypervisor(NURESTObject):
         self._separate_data_network = value
 
     
-    @property
-    def deployment_count(self):
-        """ Get deployment_count value.
-
-            Notes:
-                The number of times the vrs was deployed on this hypervisor
-
-                
-                This attribute is named `deploymentCount` in VSD API.
-                
-        """
-        return self._deployment_count
-
-    @deployment_count.setter
-    def deployment_count(self, value):
-        """ Set deployment_count value.
-
-            Notes:
-                The number of times the vrs was deployed on this hypervisor
-
-                
-                This attribute is named `deploymentCount` in VSD API.
-                
-        """
-        self._deployment_count = value
-
-    
     @property
     def personality(self):
         """ Get personality value.
@@ -1964,6 +1811,33 @@ class NUVCenterHypervisor(NURESTObject):
         self._vrs_user_name = value
 
     
+    @property
+    def associated_cluster_id(self):
+        """ Get associated_cluster_id value.
+
+            Notes:
+                The ID of the cluster to which this host is attached
+
+                
+                This attribute is named `associatedClusterID` in VSD API.
+                
+        """
+        return self._associated_cluster_id
+
+    @associated_cluster_id.setter
+    def associated_cluster_id(self, value):
+        """ Set associated_cluster_id value.
+
+            Notes:
+                The ID of the cluster to which this host is attached
+
+                
+                This attribute is named `associatedClusterID` in VSD API.
+                
+        """
+        self._associated_cluster_id = value
+
+    
     @property
     def static_route(self):
         """ Get static_route value.
@@ -2392,33 +2266,6 @@ class NUVCenterHypervisor(NURESTObject):
         self._customized_script_url = value
 
     
-    @property
-    def available_networks(self):
-        """ Get available_networks value.
-
-            Notes:
-                List of the available network list for the hypervisor.
-
-                
-                This attribute is named `availableNetworks` in VSD API.
-                
-        """
-        return self._available_networks
-
-    @available_networks.setter
-    def available_networks(self, value):
-        """ Set available_networks value.
-
-            Notes:
-                List of the available network list for the hypervisor.
-
-                
-                This attribute is named `availableNetworks` in VSD API.
-                
-        """
-        self._available_networks = value
-
-    
     @property
     def external_id(self):
         """ Get external_id value.
