@@ -74,7 +74,6 @@ class NUVCenterVRSConfig(NURESTObject):
 
         # Read/Write Attributes
         
-        self._arp_reply = None
         self._v_require_nuage_metadata = None
         self._last_updated_by = None
         self._data_dns1 = None
@@ -83,7 +82,6 @@ class NUVCenterVRSConfig(NURESTObject):
         self._data_network_portgroup = None
         self._datapath_sync_timeout = None
         self._secondary_nuage_controller = None
-        self._generic_split_activation = None
         self._separate_data_network = None
         self._personality = None
         self._metadata_server_ip = None
@@ -137,7 +135,6 @@ class NUVCenterVRSConfig(NURESTObject):
         self._customized_script_url = None
         self._external_id = None
         
-        self.expose_attribute(local_name="arp_reply", remote_name="ARPReply", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="v_require_nuage_metadata", remote_name="vRequireNuageMetadata", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="data_dns1", remote_name="dataDNS1", attribute_type=str, is_required=False, is_unique=False)
@@ -146,7 +143,6 @@ class NUVCenterVRSConfig(NURESTObject):
         self.expose_attribute(local_name="data_network_portgroup", remote_name="dataNetworkPortgroup", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="datapath_sync_timeout", remote_name="datapathSyncTimeout", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="secondary_nuage_controller", remote_name="secondaryNuageController", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="generic_split_activation", remote_name="genericSplitActivation", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="separate_data_network", remote_name="separateDataNetwork", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="personality", remote_name="personality", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="metadata_server_ip", remote_name="metadataServerIP", attribute_type=str, is_required=False, is_unique=False)
@@ -217,33 +213,6 @@ class NUVCenterVRSConfig(NURESTObject):
 
     # Properties
     
-    @property
-    def arp_reply(self):
-        """ Get arp_reply value.
-
-            Notes:
-                Whether ARP Reply is enabled/disabled
-
-                
-                This attribute is named `ARPReply` in VSD API.
-                
-        """
-        return self._arp_reply
-
-    @arp_reply.setter
-    def arp_reply(self, value):
-        """ Set arp_reply value.
-
-            Notes:
-                Whether ARP Reply is enabled/disabled
-
-                
-                This attribute is named `ARPReply` in VSD API.
-                
-        """
-        self._arp_reply = value
-
-    
     @property
     def v_require_nuage_metadata(self):
         """ Get v_require_nuage_metadata value.
@@ -460,33 +429,6 @@ class NUVCenterVRSConfig(NURESTObject):
         self._secondary_nuage_controller = value
 
     
-    @property
-    def generic_split_activation(self):
-        """ Get generic_split_activation value.
-
-            Notes:
-                Whether split-activation is needed from VRO
-
-                
-                This attribute is named `genericSplitActivation` in VSD API.
-                
-        """
-        return self._generic_split_activation
-
-    @generic_split_activation.setter
-    def generic_split_activation(self, value):
-        """ Set generic_split_activation value.
-
-            Notes:
-                Whether split-activation is needed from VRO
-
-                
-                This attribute is named `genericSplitActivation` in VSD API.
-                
-        """
-        self._generic_split_activation = value
-
-    
     @property
     def separate_data_network(self):
         """ Get separate_data_network value.
