@@ -60,15 +60,6 @@ from .fetchers import NUVMInterfacesFetcher
 from .fetchers import NUPolicyGroupsFetcher
 
 
-from .fetchers import NUContainersFetcher
-
-
-from .fetchers import NUContainerInterfacesFetcher
-
-
-from .fetchers import NUPortMappingsFetcher
-
-
 from .fetchers import NUQOSsFetcher
 
 
@@ -78,9 +69,6 @@ from .fetchers import NUHostInterfacesFetcher
 from .fetchers import NUVPortMirrorsFetcher
 
 
-from .fetchers import NUApplicationperformancemanagementsFetcher
-
-
 from .fetchers import NUBridgeInterfacesFetcher
 
 
@@ -102,7 +90,7 @@ class NUVPort(NURESTObject):
     """ Represents a VPort in the VSD
 
         Notes:
-            VPorts are a new level in the domain hierarchy, intended to provide more granular configuration than at subnet, and also support a split workflow, where the vPort is configured and associated with a VM port (or gateway port) before the port exists.
+            VPorts are a new level in the domain hierarchy, intended to provide more granular configuration than at subnet, and also support a split workflow, where the vPort is configured and associated with a VM port (or gateway port) before the port exists on the hypervisor or gateway.
     """
 
     __rest_name__ = "vport"
@@ -111,54 +99,46 @@ class NUVPort(NURESTObject):
     
     ## Constants
     
-    CONST_SYSTEM_TYPE_NUAGE_2 = "NUAGE_2"
+    CONST_OPERATIONAL_STATE_DOWN = "DOWN"
     
     CONST_SYSTEM_TYPE_NUAGE_1 = "NUAGE_1"
     
-    CONST_DPI_ENABLED = "ENABLED"
-    
-    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
-    
-    CONST_TYPE_CONTAINER = "CONTAINER"
-    
-    CONST_DPI_INHERITED = "INHERITED"
-    
-    CONST_ADDRESS_SPOOFING_DISABLED = "DISABLED"
-    
-    CONST_ADDRESS_SPOOFING_INHERITED = "INHERITED"
-    
-    CONST_TYPE_HOST = "HOST"
-    
-    CONST_ADDRESS_SPOOFING_ENABLED = "ENABLED"
-    
-    CONST_SYSTEM_TYPE_SOFTWARE = "SOFTWARE"
-    
-    CONST_OPERATIONAL_STATE_DOWN = "DOWN"
-    
-    CONST_OPERATIONAL_STATE_UP = "UP"
-    
-    CONST_MULTICAST_ENABLED = "ENABLED"
-    
-    CONST_MULTICAST_INHERITED = "INHERITED"
-    
-    CONST_SYSTEM_TYPE_HARDWARE_VTEP = "HARDWARE_VTEP"
-    
     CONST_SYSTEM_TYPE_HARDWARE = "HARDWARE"
     
-    CONST_TYPE_BRIDGE = "BRIDGE"
-    
     CONST_MULTICAST_DISABLED = "DISABLED"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
-    CONST_DPI_DISABLED = "DISABLED"
+    CONST_SYSTEM_TYPE_HARDWARE_VTEP = "HARDWARE_VTEP"
+    
+    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    
+    CONST_OPERATIONAL_STATE_UP = "UP"
     
     CONST_SYSTEM_TYPE_NUAGE_VRSG = "NUAGE_VRSG"
     
+    CONST_MULTICAST_ENABLED = "ENABLED"
+    
+    CONST_MULTICAST_INHERITED = "INHERITED"
+    
+    CONST_TYPE_HOST = "HOST"
+    
+    CONST_ADDRESS_SPOOFING_DISABLED = "DISABLED"
+    
+    CONST_SYSTEM_TYPE_NUAGE_2 = "NUAGE_2"
+    
+    CONST_ADDRESS_SPOOFING_INHERITED = "INHERITED"
+    
     CONST_OPERATIONAL_STATE_INIT = "INIT"
     
+    CONST_SYSTEM_TYPE_SOFTWARE = "SOFTWARE"
+    
     CONST_TYPE_VM = "VM"
     
+    CONST_ADDRESS_SPOOFING_ENABLED = "ENABLED"
+    
+    CONST_TYPE_BRIDGE = "BRIDGE"
+    
     
 
     def __init__(self, **kwargs):
@@ -179,7 +159,6 @@ class NUVPort(NURESTObject):
         # Read/Write Attributes
         
         self._vlanid = None
-        self._dpi = None
         self._name = None
         self._has_attached_interfaces = None
         self._last_updated_by = None
@@ -200,7 +179,6 @@ class NUVPort(NURESTObject):
         self._system_type = None
         
         self.expose_attribute(local_name="vlanid", remote_name="VLANID", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="dpi", remote_name="DPI", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="has_attached_interfaces", remote_name="hasAttachedInterfaces", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
@@ -217,7 +195,7 @@ class NUVPort(NURESTObject):
         self.expose_attribute(local_name="multi_nic_vport_id", remote_name="multiNICVPortID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="multicast", remote_name="multicast", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'ENABLED', u'INHERITED'])
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
-        self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=True, is_unique=False, choices=[u'BRIDGE', u'CONTAINER', u'HOST', u'VM'])
+        self.expose_attribute(local_name="type", remote_name="type", attribute_type=str, is_required=True, is_unique=False, choices=[u'BRIDGE', u'HOST', u'VM'])
         self.expose_attribute(local_name="system_type", remote_name="systemType", attribute_type=str, is_required=False, is_unique=False, choices=[u'HARDWARE', u'HARDWARE_VTEP', u'NUAGE_1', u'NUAGE_2', u'NUAGE_VRSG', u'SOFTWARE'])
         
 
@@ -257,15 +235,6 @@ class NUVPort(NURESTObject):
         self.policy_groups = NUPolicyGroupsFetcher.fetcher_with_object(parent_object=self, relationship="member")
         
         
-        self.containers = NUContainersFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.container_interfaces = NUContainerInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
-        self.port_mappings = NUPortMappingsFetcher.fetcher_with_object(parent_object=self, relationship="child")
-        
-        
         self.qoss = NUQOSsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -275,9 +244,6 @@ class NUVPort(NURESTObject):
         self.vport_mirrors = NUVPortMirrorsFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.applicationperformancemanagements = NUApplicationperformancemanagementsFetcher.fetcher_with_object(parent_object=self, relationship="member")
-        
-        
         self.bridge_interfaces = NUBridgeInterfacesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
@@ -324,33 +290,6 @@ class NUVPort(NURESTObject):
         self._vlanid = value
 
     
-    @property
-    def dpi(self):
-        """ Get dpi value.
-
-            Notes:
-                determines whether or not Deep packet inspection is enabled
-
-                
-                This attribute is named `DPI` in VSD API.
-                
-        """
-        return self._dpi
-
-    @dpi.setter
-    def dpi(self, value):
-        """ Set dpi value.
-
-            Notes:
-                determines whether or not Deep packet inspection is enabled
-
-                
-                This attribute is named `DPI` in VSD API.
-                
-        """
-        self._dpi = value
-
-    
     @property
     def name(self):
         """ Get name value.
