@@ -105,6 +105,7 @@ class NUEnterpriseProfile(NURESTObject):
 
         # Read/Write Attributes
         
+        self._bgp_enabled = None
         self._dhcp_lease_interval = None
         self._name = None
         self._last_updated_by = None
@@ -116,10 +117,12 @@ class NUEnterpriseProfile(NURESTObject):
         self._allow_trusted_forwarding_class = None
         self._allowed_forwarding_classes = None
         self._floating_ips_quota = None
+        self._enable_application_performance_management = None
         self._encryption_management_mode = None
         self._entity_scope = None
         self._external_id = None
         
+        self.expose_attribute(local_name="bgp_enabled", remote_name="BGPEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="dhcp_lease_interval", remote_name="DHCPLeaseInterval", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
@@ -131,6 +134,7 @@ class NUEnterpriseProfile(NURESTObject):
         self.expose_attribute(local_name="allow_trusted_forwarding_class", remote_name="allowTrustedForwardingClass", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_forwarding_classes", remote_name="allowedForwardingClasses", attribute_type=list, is_required=False, is_unique=False, choices=[u'A', u'B', u'C', u'D', u'E', u'F', u'G', u'H', u'NONE'])
         self.expose_attribute(local_name="floating_ips_quota", remote_name="floatingIPsQuota", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="enable_application_performance_management", remote_name="enableApplicationPerformanceManagement", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="encryption_management_mode", remote_name="encryptionManagementMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'MANAGED'])
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
@@ -145,7 +149,7 @@ class NUEnterpriseProfile(NURESTObject):
         self.global_metadatas = NUGlobalMetadatasFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
-        self.enterprises = NUEnterprisesFetcher.fetcher_with_object(parent_object=self, relationship="member")
+        self.enterprises = NUEnterprisesFetcher.fetcher_with_object(parent_object=self, relationship="child")
         
         
         self.multi_cast_lists = NUMultiCastListsFetcher.fetcher_with_object(parent_object=self, relationship="child")
@@ -161,6 +165,33 @@ class NUEnterpriseProfile(NURESTObject):
 
     # Properties
     
+    @property
+    def bgp_enabled(self):
+        """ Get bgp_enabled value.
+
+            Notes:
+                Enable BGP for this enterprise profile
+
+                
+                This attribute is named `BGPEnabled` in VSD API.
+                
+        """
+        return self._bgp_enabled
+
+    @bgp_enabled.setter
+    def bgp_enabled(self, value):
+        """ Set bgp_enabled value.
+
+            Notes:
+                Enable BGP for this enterprise profile
+
+                
+                This attribute is named `BGPEnabled` in VSD API.
+                
+        """
+        self._bgp_enabled = value
+
+    
     @property
     def dhcp_lease_interval(self):
         """ Get dhcp_lease_interval value.
@@ -450,6 +481,33 @@ class NUEnterpriseProfile(NURESTObject):
         self._floating_ips_quota = value
 
     
+    @property
+    def enable_application_performance_management(self):
+        """ Get enable_application_performance_management value.
+
+            Notes:
+                Enable DPI for this enterprise
+
+                
+                This attribute is named `enableApplicationPerformanceManagement` in VSD API.
+                
+        """
+        return self._enable_application_performance_management
+
+    @enable_application_performance_management.setter
+    def enable_application_performance_management(self, value):
+        """ Set enable_application_performance_management value.
+
+            Notes:
+                Enable DPI for this enterprise
+
+                
+                This attribute is named `enableApplicationPerformanceManagement` in VSD API.
+                
+        """
+        self._enable_application_performance_management = value
+
+    
     @property
     def encryption_management_mode(self):
         """ Get encryption_management_mode value.
