@@ -48,66 +48,36 @@ class NUInfrastructureGatewayProfile(NURESTObject):
     
     ## Constants
     
-    CONST_DEAD_TIMER_THREE_HOURS = "THREE_HOURS"
-    
-    CONST_SYSTEM_SYNC_WINDOW_SIX_HOURS = "SIX_HOURS"
-    
-    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
-    
-    CONST_REMOTE_LOG_MODE_DISABLED = "DISABLED"
-    
-    CONST_REMOTE_LOG_MODE_SFTP = "SFTP"
-    
-    CONST_UPGRADE_ACTION_DOWNLOAD_ONLY = "DOWNLOAD_ONLY"
-    
-    CONST_DEAD_TIMER_FOUR_HOURS = "FOUR_HOURS"
-    
-    CONST_SYSTEM_SYNC_WINDOW_FOUR_HOURS = "FOUR_HOURS"
-    
-    CONST_SYSTEM_SYNC_WINDOW_THREE_HOURS = "THREE_HOURS"
-    
-    CONST_DEAD_TIMER_TEN_MINUTES = "TEN_MINUTES"
-    
-    CONST_DEAD_TIMER_THIRTY_MINUTES = "THIRTY_MINUTES"
-    
-    CONST_UPGRADE_ACTION_UPGRADE_AT_BOOTSTRAPPING = "UPGRADE_AT_BOOTSTRAPPING"
-    
-    CONST_SYSTEM_SYNC_WINDOW_THIRTY_MINUTES = "THIRTY_MINUTES"
-    
-    CONST_UPGRADE_ACTION_NONE = "NONE"
-    
-    CONST_SYSTEM_SYNC_WINDOW_NONE = "NONE"
-    
-    CONST_SYSTEM_SYNC_WINDOW_TWO_HOURS = "TWO_HOURS"
-    
-    CONST_DEAD_TIMER_FIVE_HOURS = "FIVE_HOURS"
-    
-    CONST_DEAD_TIMER_NONE = "NONE"
-    
-    CONST_UPGRADE_ACTION_UPGRADE_NOW = "UPGRADE_NOW"
-    
-    CONST_DEAD_TIMER_SIX_HOURS = "SIX_HOURS"
-    
-    CONST_SYSTEM_SYNC_WINDOW_TEN_MINUTES = "TEN_MINUTES"
-    
-    CONST_SYSTEM_SYNC_WINDOW_FIVE_HOURS = "FIVE_HOURS"
-    
-    CONST_UPGRADE_ACTION_DOWNLOAD_AND_UPGRADE_AT_WINDOW = "DOWNLOAD_AND_UPGRADE_AT_WINDOW"
-    
     CONST_REMOTE_LOG_MODE_SCP = "SCP"
     
-    CONST_DEAD_TIMER_TWO_HOURS = "TWO_HOURS"
+    CONST_CONTROLLER_LESS_FORWARDING_MODE_LOCAL_AND_REMOTE = "LOCAL_AND_REMOTE"
+    
+    CONST_UPGRADE_ACTION_NONE = "NONE"
     
     CONST_ENTITY_SCOPE_GLOBAL = "GLOBAL"
     
     CONST_REMOTE_LOG_MODE_RSYSLOG = "RSYSLOG"
     
-    CONST_DEAD_TIMER_ONE_HOUR = "ONE_HOUR"
-    
-    CONST_SYSTEM_SYNC_WINDOW_ONE_HOUR = "ONE_HOUR"
-    
     CONST_UPGRADE_ACTION_DOWNLOAD_AND_UPGRADE_NOW = "DOWNLOAD_AND_UPGRADE_NOW"
     
+    CONST_ENTITY_SCOPE_ENTERPRISE = "ENTERPRISE"
+    
+    CONST_CONTROLLER_LESS_FORWARDING_MODE_DISABLED = "DISABLED"
+    
+    CONST_REMOTE_LOG_MODE_DISABLED = "DISABLED"
+    
+    CONST_UPGRADE_ACTION_UPGRADE_AT_BOOTSTRAPPING = "UPGRADE_AT_BOOTSTRAPPING"
+    
+    CONST_REMOTE_LOG_MODE_SFTP = "SFTP"
+    
+    CONST_UPGRADE_ACTION_DOWNLOAD_ONLY = "DOWNLOAD_ONLY"
+    
+    CONST_UPGRADE_ACTION_UPGRADE_NOW = "UPGRADE_NOW"
+    
+    CONST_UPGRADE_ACTION_DOWNLOAD_AND_UPGRADE_AT_WINDOW = "DOWNLOAD_AND_UPGRADE_AT_WINDOW"
+    
+    CONST_CONTROLLER_LESS_FORWARDING_MODE_LOCAL_ONLY = "LOCAL_ONLY"
+    
     
 
     def __init__(self, **kwargs):
@@ -133,49 +103,55 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         self._last_updated_by = None
         self._datapath_sync_timeout = None
         self._dead_timer = None
-        self._remote_log_dir_path = None
+        self._dead_timer_enabled = None
         self._remote_log_mode = None
-        self._remote_log_password = None
         self._remote_log_server_address = None
         self._remote_log_server_port = None
-        self._remote_log_username = None
         self._description = None
         self._metadata_upgrade_path = None
         self._flow_eviction_threshold = None
         self._enterprise_id = None
         self._entity_scope = None
+        self._controller_less_duration = None
+        self._controller_less_enabled = None
+        self._controller_less_forwarding_mode = None
+        self._controller_less_remote_duration = None
+        self._force_immediate_system_sync = None
+        self._open_flow_audit_timer = None
         self._upgrade_action = None
         self._proxy_dns_name = None
         self._use_two_factor = None
         self._stats_collector_port = None
         self._external_id = None
         self._system_sync_scheduler = None
-        self._system_sync_window = None
         
         self.expose_attribute(local_name="ntp_server_key", remote_name="NTPServerKey", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="ntp_server_key_id", remote_name="NTPServerKeyID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="name", remote_name="name", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="datapath_sync_timeout", remote_name="datapathSyncTimeout", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="dead_timer", remote_name="deadTimer", attribute_type=str, is_required=False, is_unique=False, choices=[u'FIVE_HOURS', u'FOUR_HOURS', u'NONE', u'ONE_HOUR', u'SIX_HOURS', u'TEN_MINUTES', u'THIRTY_MINUTES', u'THREE_HOURS', u'TWO_HOURS'])
-        self.expose_attribute(local_name="remote_log_dir_path", remote_name="remoteLogDirPath", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="dead_timer", remote_name="deadTimer", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="dead_timer_enabled", remote_name="deadTimerEnabled", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="remote_log_mode", remote_name="remoteLogMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'RSYSLOG', u'SCP', u'SFTP'])
-        self.expose_attribute(local_name="remote_log_password", remote_name="remoteLogPassword", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="remote_log_server_address", remote_name="remoteLogServerAddress", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="remote_log_server_port", remote_name="remoteLogServerPort", attribute_type=int, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="remote_log_username", remote_name="remoteLogUsername", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="description", remote_name="description", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="metadata_upgrade_path", remote_name="metadataUpgradePath", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="flow_eviction_threshold", remote_name="flowEvictionThreshold", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="enterprise_id", remote_name="enterpriseID", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
+        self.expose_attribute(local_name="controller_less_duration", remote_name="controllerLessDuration", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="controller_less_enabled", remote_name="controllerLessEnabled", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="controller_less_forwarding_mode", remote_name="controllerLessForwardingMode", attribute_type=str, is_required=False, is_unique=False, choices=[u'DISABLED', u'LOCAL_AND_REMOTE', u'LOCAL_ONLY'])
+        self.expose_attribute(local_name="controller_less_remote_duration", remote_name="controllerLessRemoteDuration", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="force_immediate_system_sync", remote_name="forceImmediateSystemSync", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="open_flow_audit_timer", remote_name="openFlowAuditTimer", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="upgrade_action", remote_name="upgradeAction", attribute_type=str, is_required=False, is_unique=False, choices=[u'DOWNLOAD_AND_UPGRADE_AT_WINDOW', u'DOWNLOAD_AND_UPGRADE_NOW', u'DOWNLOAD_ONLY', u'NONE', u'UPGRADE_AT_BOOTSTRAPPING', u'UPGRADE_NOW'])
         self.expose_attribute(local_name="proxy_dns_name", remote_name="proxyDNSName", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="use_two_factor", remote_name="useTwoFactor", attribute_type=bool, is_required=False, is_unique=False)
         self.expose_attribute(local_name="stats_collector_port", remote_name="statsCollectorPort", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         self.expose_attribute(local_name="system_sync_scheduler", remote_name="systemSyncScheduler", attribute_type=str, is_required=False, is_unique=False)
-        self.expose_attribute(local_name="system_sync_window", remote_name="systemSyncWindow", attribute_type=str, is_required=False, is_unique=False, choices=[u'FIVE_HOURS', u'FOUR_HOURS', u'NONE', u'ONE_HOUR', u'SIX_HOURS', u'TEN_MINUTES', u'THIRTY_MINUTES', u'THREE_HOURS', u'TWO_HOURS'])
         
 
         # Fetchers
@@ -300,7 +276,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Get datapath_sync_timeout value.
 
             Notes:
-                Datapath flows sync-time-interval specified in milliseconds (default: 1000)
+                Datapath flows sync-time-interval specified in milliseconds
 
                 
                 This attribute is named `datapathSyncTimeout` in VSD API.
@@ -313,7 +289,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Set datapath_sync_timeout value.
 
             Notes:
-                Datapath flows sync-time-interval specified in milliseconds (default: 1000)
+                Datapath flows sync-time-interval specified in milliseconds
 
                 
                 This attribute is named `datapathSyncTimeout` in VSD API.
@@ -327,7 +303,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Get dead_timer value.
 
             Notes:
-                Time, in seconds, allowed for a Gateway to be inactive before the VSD revokes its certificates and marks it as untrusted.
+                ISO 8601 format duration: **P nYnMnD T nHnMnS**. **P** represents the period field and **T** the time field. Period field: **Y** = year, **M** = month, **D** = day. Time field: **H** = hours, **M** = minutes, **S** = seconds. **n** is the value of each field. Because the years and month are units that vary in length, for the time being those are not supported yet.
 
                 
                 This attribute is named `deadTimer` in VSD API.
@@ -340,7 +316,7 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         """ Set dead_timer value.
 
             Notes:
-                Time, in seconds, allowed for a Gateway to be inactive before the VSD revokes its certificates and marks it as untrusted.
+                ISO 8601 format duration: **P nYnMnD T nHnMnS**. **P** represents the period field and **T** the time field. Period field: **Y** = year, **M** = month, **D** = day. Time field: **H** = hours, **M** = minutes, **S** = seconds. **n** is the value of each field. Because the years and month are units that vary in length, for the time being those are not supported yet.
 
                 
                 This attribute is named `deadTimer` in VSD API.
@@ -350,30 +326,30 @@ class NUInfrastructureGatewayProfile(NURESTObject):
 
     
     @property
-    def remote_log_dir_path(self):
-        """ Get remote_log_dir_path value.
+    def dead_timer_enabled(self):
+        """ Get dead_timer_enabled value.
 
             Notes:
-                Path on the remote log server where the logs generated by the NSG are to be stored.  This field is only useful for SCP and SFTP.
+                Flag to enable automatic deactivation.
 
                 
-                This attribute is named `remoteLogDirPath` in VSD API.
+                This attribute is named `deadTimerEnabled` in VSD API.
                 
         """
-        return self._remote_log_dir_path
+        return self._dead_timer_enabled
 
-    @remote_log_dir_path.setter
-    def remote_log_dir_path(self, value):
-        """ Set remote_log_dir_path value.
+    @dead_timer_enabled.setter
+    def dead_timer_enabled(self, value):
+        """ Set dead_timer_enabled value.
 
             Notes:
-                Path on the remote log server where the logs generated by the NSG are to be stored.  This field is only useful for SCP and SFTP.
+                Flag to enable automatic deactivation.
 
                 
-                This attribute is named `remoteLogDirPath` in VSD API.
+                This attribute is named `deadTimerEnabled` in VSD API.
                 
         """
-        self._remote_log_dir_path = value
+        self._dead_timer_enabled = value
 
     
     @property
@@ -403,33 +379,6 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         self._remote_log_mode = value
 
     
-    @property
-    def remote_log_password(self):
-        """ Get remote_log_password value.
-
-            Notes:
-                Password to be used when accessing the remote log server via SCP or SFTP.  This field is only useful for SCP and SFTP.
-
-                
-                This attribute is named `remoteLogPassword` in VSD API.
-                
-        """
-        return self._remote_log_password
-
-    @remote_log_password.setter
-    def remote_log_password(self, value):
-        """ Set remote_log_password value.
-
-            Notes:
-                Password to be used when accessing the remote log server via SCP or SFTP.  This field is only useful for SCP and SFTP.
-
-                
-                This attribute is named `remoteLogPassword` in VSD API.
-                
-        """
-        self._remote_log_password = value
-
-    
     @property
     def remote_log_server_address(self):
         """ Get remote_log_server_address value.
@@ -484,33 +433,6 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         self._remote_log_server_port = value
 
     
-    @property
-    def remote_log_username(self):
-        """ Get remote_log_username value.
-
-            Notes:
-                Username to be used when accessing the remote log server via SCP or SFTP.  This field is only useful for SCP and SFTP.
-
-                
-                This attribute is named `remoteLogUsername` in VSD API.
-                
-        """
-        return self._remote_log_username
-
-    @remote_log_username.setter
-    def remote_log_username(self, value):
-        """ Set remote_log_username value.
-
-            Notes:
-                Username to be used when accessing the remote log server via SCP or SFTP.  This field is only useful for SCP and SFTP.
-
-                
-                This attribute is named `remoteLogUsername` in VSD API.
-                
-        """
-        self._remote_log_username = value
-
-    
     @property
     def description(self):
         """ Get description value.
@@ -642,6 +564,168 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         self._entity_scope = value
 
     
+    @property
+    def controller_less_duration(self):
+        """ Get controller_less_duration value.
+
+            Notes:
+                Duration for a controller-less local operation (in ISO-duration format).
+
+                
+                This attribute is named `controllerLessDuration` in VSD API.
+                
+        """
+        return self._controller_less_duration
+
+    @controller_less_duration.setter
+    def controller_less_duration(self, value):
+        """ Set controller_less_duration value.
+
+            Notes:
+                Duration for a controller-less local operation (in ISO-duration format).
+
+                
+                This attribute is named `controllerLessDuration` in VSD API.
+                
+        """
+        self._controller_less_duration = value
+
+    
+    @property
+    def controller_less_enabled(self):
+        """ Get controller_less_enabled value.
+
+            Notes:
+                Flag to enable controller-less operations.
+
+                
+                This attribute is named `controllerLessEnabled` in VSD API.
+                
+        """
+        return self._controller_less_enabled
+
+    @controller_less_enabled.setter
+    def controller_less_enabled(self, value):
+        """ Set controller_less_enabled value.
+
+            Notes:
+                Flag to enable controller-less operations.
+
+                
+                This attribute is named `controllerLessEnabled` in VSD API.
+                
+        """
+        self._controller_less_enabled = value
+
+    
+    @property
+    def controller_less_forwarding_mode(self):
+        """ Get controller_less_forwarding_mode value.
+
+            Notes:
+                The forwarding mode to use for controllerLess operations
+
+                
+                This attribute is named `controllerLessForwardingMode` in VSD API.
+                
+        """
+        return self._controller_less_forwarding_mode
+
+    @controller_less_forwarding_mode.setter
+    def controller_less_forwarding_mode(self, value):
+        """ Set controller_less_forwarding_mode value.
+
+            Notes:
+                The forwarding mode to use for controllerLess operations
+
+                
+                This attribute is named `controllerLessForwardingMode` in VSD API.
+                
+        """
+        self._controller_less_forwarding_mode = value
+
+    
+    @property
+    def controller_less_remote_duration(self):
+        """ Get controller_less_remote_duration value.
+
+            Notes:
+                Duration for a controller-less remote operation (in ISO-duration format).
+
+                
+                This attribute is named `controllerLessRemoteDuration` in VSD API.
+                
+        """
+        return self._controller_less_remote_duration
+
+    @controller_less_remote_duration.setter
+    def controller_less_remote_duration(self, value):
+        """ Set controller_less_remote_duration value.
+
+            Notes:
+                Duration for a controller-less remote operation (in ISO-duration format).
+
+                
+                This attribute is named `controllerLessRemoteDuration` in VSD API.
+                
+        """
+        self._controller_less_remote_duration = value
+
+    
+    @property
+    def force_immediate_system_sync(self):
+        """ Get force_immediate_system_sync value.
+
+            Notes:
+                Usually the synchronization will span across 1 hour window after the defined synchronization time. Forcing an immediate synchronization can overload the system and can have a negative impact on the system.
+
+                
+                This attribute is named `forceImmediateSystemSync` in VSD API.
+                
+        """
+        return self._force_immediate_system_sync
+
+    @force_immediate_system_sync.setter
+    def force_immediate_system_sync(self, value):
+        """ Set force_immediate_system_sync value.
+
+            Notes:
+                Usually the synchronization will span across 1 hour window after the defined synchronization time. Forcing an immediate synchronization can overload the system and can have a negative impact on the system.
+
+                
+                This attribute is named `forceImmediateSystemSync` in VSD API.
+                
+        """
+        self._force_immediate_system_sync = value
+
+    
+    @property
+    def open_flow_audit_timer(self):
+        """ Get open_flow_audit_timer value.
+
+            Notes:
+                Openflow audit timer in sec. Upon the expiry of this timer a set of cleanup operations will be performed
+
+                
+                This attribute is named `openFlowAuditTimer` in VSD API.
+                
+        """
+        return self._open_flow_audit_timer
+
+    @open_flow_audit_timer.setter
+    def open_flow_audit_timer(self, value):
+        """ Set open_flow_audit_timer value.
+
+            Notes:
+                Openflow audit timer in sec. Upon the expiry of this timer a set of cleanup operations will be performed
+
+                
+                This attribute is named `openFlowAuditTimer` in VSD API.
+                
+        """
+        self._open_flow_audit_timer = value
+
+    
     @property
     def upgrade_action(self):
         """ Get upgrade_action value.
@@ -804,32 +888,5 @@ class NUInfrastructureGatewayProfile(NURESTObject):
         self._system_sync_scheduler = value
 
     
-    @property
-    def system_sync_window(self):
-        """ Get system_sync_window value.
-
-            Notes:
-                Length of time, in seconds, given to a Gateway to apply a configuration change.  This property is closely linked to systemSyncScheduler.
-
-                
-                This attribute is named `systemSyncWindow` in VSD API.
-                
-        """
-        return self._system_sync_window
-
-    @system_sync_window.setter
-    def system_sync_window(self, value):
-        """ Set system_sync_window value.
-
-            Notes:
-                Length of time, in seconds, given to a Gateway to apply a configuration change.  This property is closely linked to systemSyncScheduler.
-
-                
-                This attribute is named `systemSyncWindow` in VSD API.
-                
-        """
-        self._system_sync_window = value
-
-    
 
     
\ No newline at end of file
