@@ -84,14 +84,18 @@ class NULicense(NURESTObject):
         
         self._major_release = None
         self._last_updated_by = None
+        self._additional_supported_versions = None
         self._phone = None
         self._license = None
         self._license_encryption = None
+        self._license_entities = None
         self._license_id = None
         self._license_type = None
         self._minor_release = None
         self._zip = None
         self._city = None
+        self._allowed_avrsgs_count = None
+        self._allowed_avrss_count = None
         self._allowed_cpes_count = None
         self._allowed_nics_count = None
         self._allowed_vms_count = None
@@ -99,6 +103,7 @@ class NULicense(NURESTObject):
         self._allowed_vrss_count = None
         self._email = None
         self._encryption_mode = None
+        self._unique_license_identifier = None
         self._entity_scope = None
         self._company = None
         self._country = None
@@ -110,18 +115,23 @@ class NULicense(NURESTObject):
         self._street = None
         self._customer_key = None
         self._expiration_date = None
+        self._expiry_timestamp = None
         self._external_id = None
         
         self.expose_attribute(local_name="major_release", remote_name="majorRelease", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="last_updated_by", remote_name="lastUpdatedBy", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="additional_supported_versions", remote_name="additionalSupportedVersions", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="phone", remote_name="phone", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="license", remote_name="license", attribute_type=str, is_required=True, is_unique=False)
         self.expose_attribute(local_name="license_encryption", remote_name="licenseEncryption", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENCRYPTION_DISABLED', u'ENCRYPTION_ENABLED'])
+        self.expose_attribute(local_name="license_entities", remote_name="licenseEntities", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="license_id", remote_name="licenseID", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="license_type", remote_name="licenseType", attribute_type=str, is_required=False, is_unique=False, choices=[u'CLUSTERED', u'STANDARD'])
         self.expose_attribute(local_name="minor_release", remote_name="minorRelease", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="zip", remote_name="zip", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="city", remote_name="city", attribute_type=str, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="allowed_avrsgs_count", remote_name="allowedAVRSGsCount", attribute_type=int, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="allowed_avrss_count", remote_name="allowedAVRSsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_cpes_count", remote_name="allowedCPEsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_nics_count", remote_name="allowedNICsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="allowed_vms_count", remote_name="allowedVMsCount", attribute_type=int, is_required=False, is_unique=False)
@@ -129,6 +139,7 @@ class NULicense(NURESTObject):
         self.expose_attribute(local_name="allowed_vrss_count", remote_name="allowedVRSsCount", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="email", remote_name="email", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="encryption_mode", remote_name="encryptionMode", attribute_type=bool, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="unique_license_identifier", remote_name="uniqueLicenseIdentifier", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="entity_scope", remote_name="entityScope", attribute_type=str, is_required=False, is_unique=False, choices=[u'ENTERPRISE', u'GLOBAL'])
         self.expose_attribute(local_name="company", remote_name="company", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="country", remote_name="country", attribute_type=str, is_required=False, is_unique=False)
@@ -140,6 +151,7 @@ class NULicense(NURESTObject):
         self.expose_attribute(local_name="street", remote_name="street", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="customer_key", remote_name="customerKey", attribute_type=str, is_required=False, is_unique=False)
         self.expose_attribute(local_name="expiration_date", remote_name="expirationDate", attribute_type=float, is_required=False, is_unique=False)
+        self.expose_attribute(local_name="expiry_timestamp", remote_name="expiryTimestamp", attribute_type=int, is_required=False, is_unique=False)
         self.expose_attribute(local_name="external_id", remote_name="externalID", attribute_type=str, is_required=False, is_unique=True)
         
 
@@ -213,6 +225,33 @@ class NULicense(NURESTObject):
         self._last_updated_by = value
 
     
+    @property
+    def additional_supported_versions(self):
+        """ Get additional_supported_versions value.
+
+            Notes:
+                Indicates additional versions supported by the license.
+
+                
+                This attribute is named `additionalSupportedVersions` in VSD API.
+                
+        """
+        return self._additional_supported_versions
+
+    @additional_supported_versions.setter
+    def additional_supported_versions(self, value):
+        """ Set additional_supported_versions value.
+
+            Notes:
+                Indicates additional versions supported by the license.
+
+                
+                This attribute is named `additionalSupportedVersions` in VSD API.
+                
+        """
+        self._additional_supported_versions = value
+
+    
     @property
     def phone(self):
         """ Get phone value.
@@ -286,6 +325,33 @@ class NULicense(NURESTObject):
         self._license_encryption = value
 
     
+    @property
+    def license_entities(self):
+        """ Get license_entities value.
+
+            Notes:
+                Indicates non enforceable entities associated with the license. 
+
+                
+                This attribute is named `licenseEntities` in VSD API.
+                
+        """
+        return self._license_entities
+
+    @license_entities.setter
+    def license_entities(self, value):
+        """ Set license_entities value.
+
+            Notes:
+                Indicates non enforceable entities associated with the license. 
+
+                
+                This attribute is named `licenseEntities` in VSD API.
+                
+        """
+        self._license_entities = value
+
+    
     @property
     def license_id(self):
         """ Get license_id value.
@@ -318,7 +384,7 @@ class NULicense(NURESTObject):
         """ Get license_type value.
 
             Notes:
-                
+                None
 
                 
                 This attribute is named `licenseType` in VSD API.
@@ -331,7 +397,7 @@ class NULicense(NURESTObject):
         """ Set license_type value.
 
             Notes:
-                
+                None
 
                 
                 This attribute is named `licenseType` in VSD API.
@@ -413,6 +479,60 @@ class NULicense(NURESTObject):
         self._city = value
 
     
+    @property
+    def allowed_avrsgs_count(self):
+        """ Get allowed_avrsgs_count value.
+
+            Notes:
+                Maximum number of AVRSGs enabled with this license. A value of -1 indicates an unlimited number of AVRSGs
+
+                
+                This attribute is named `allowedAVRSGsCount` in VSD API.
+                
+        """
+        return self._allowed_avrsgs_count
+
+    @allowed_avrsgs_count.setter
+    def allowed_avrsgs_count(self, value):
+        """ Set allowed_avrsgs_count value.
+
+            Notes:
+                Maximum number of AVRSGs enabled with this license. A value of -1 indicates an unlimited number of AVRSGs
+
+                
+                This attribute is named `allowedAVRSGsCount` in VSD API.
+                
+        """
+        self._allowed_avrsgs_count = value
+
+    
+    @property
+    def allowed_avrss_count(self):
+        """ Get allowed_avrss_count value.
+
+            Notes:
+                Maximum number of AVRSs enabled with this license. A value of -1 indicates an unlimited number of AVRSs
+
+                
+                This attribute is named `allowedAVRSsCount` in VSD API.
+                
+        """
+        return self._allowed_avrss_count
+
+    @allowed_avrss_count.setter
+    def allowed_avrss_count(self, value):
+        """ Set allowed_avrss_count value.
+
+            Notes:
+                Maximum number of AVRSs enabled with this license. A value of -1 indicates an unlimited number of AVRSs
+
+                
+                This attribute is named `allowedAVRSsCount` in VSD API.
+                
+        """
+        self._allowed_avrss_count = value
+
+    
     @property
     def allowed_cpes_count(self):
         """ Get allowed_cpes_count value.
@@ -598,6 +718,33 @@ class NULicense(NURESTObject):
         self._encryption_mode = value
 
     
+    @property
+    def unique_license_identifier(self):
+        """ Get unique_license_identifier value.
+
+            Notes:
+                Indicates combined string of first 16 and last 16 characters of the license string to be shown in the API
+
+                
+                This attribute is named `uniqueLicenseIdentifier` in VSD API.
+                
+        """
+        return self._unique_license_identifier
+
+    @unique_license_identifier.setter
+    def unique_license_identifier(self, value):
+        """ Set unique_license_identifier value.
+
+            Notes:
+                Indicates combined string of first 16 and last 16 characters of the license string to be shown in the API
+
+                
+                This attribute is named `uniqueLicenseIdentifier` in VSD API.
+                
+        """
+        self._unique_license_identifier = value
+
+    
     @property
     def entity_scope(self):
         """ Get entity_scope value.
@@ -875,6 +1022,33 @@ class NULicense(NURESTObject):
         self._expiration_date = value
 
     
+    @property
+    def expiry_timestamp(self):
+        """ Get expiry_timestamp value.
+
+            Notes:
+                The Timestamp value of the expiration date of this license
+
+                
+                This attribute is named `expiryTimestamp` in VSD API.
+                
+        """
+        return self._expiry_timestamp
+
+    @expiry_timestamp.setter
+    def expiry_timestamp(self, value):
+        """ Set expiry_timestamp value.
+
+            Notes:
+                The Timestamp value of the expiration date of this license
+
+                
+                This attribute is named `expiryTimestamp` in VSD API.
+                
+        """
+        self._expiry_timestamp = value
+
+    
     @property
     def external_id(self):
         """ Get external_id value.
